summaryrefslogtreecommitdiffstats
path: root/kio/kio/slave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/slave.cpp')
-rw-r--r--kio/kio/slave.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kio/kio/slave.cpp b/kio/kio/slave.cpp
index 4826c8da8..3a501d681 100644
--- a/kio/kio/slave.cpp
+++ b/kio/kio/slave.cpp
@@ -390,8 +390,8 @@ Slave* Slave::createSlave( const TQString &protocol, const KURL& url, int& error
// for the slave to connect to the application.
// In such case we start the slave via KProcess.
// It's possible to force this by setting the env. variable
- // KDE_FORK_SLAVES, Clearcase seems to require this.
- static bool bForkSlaves = !TQCString(getenv("KDE_FORK_SLAVES")).isEmpty();
+ // TDE_FORK_SLAVES, Clearcase seems to require this.
+ static bool bForkSlaves = !TQCString(getenv("TDE_FORK_SLAVES")).isEmpty();
if (bForkSlaves || !client->isAttached() || client->isAttachedToForeignServer())
{